/*
Analysis Dataset Cleaning - Year 2

Summary:
	Crosswalks treatment, revenue, and HR data, then cleans and compiles into
	a single dataset ready for analysis

Input:
	Circle-level treatment, revenue, and HR data

Output:
	- Cleaned & compiled data ready for Y2 analysis
	- Cleaned treatment list w/ HR data (revenue excluded)
	- Cleaned & compiled data ready for Y2 analysis, w Y1 treatment status

Notes:
	- Make sure to run TP Analysis/Do files/set_directory.do first
	- Make sure to specify what the latest quarter is
*/


clear all
set more off
cap cd "$PAKTAX2_ANALYSIS"

****************************************************
* IMPORTANT: ensure this is set to latest quarter  *
****************************************************

local latest_qtr = 4 

****************************************************
* 1. Load baseline & 2015 revenue data
****************************************************

* Save year 1 ballot circle IDs
insheet using "Data/Raw Data/Administrative Data/120904 Crosswalk to Randomization_All.csv", comma clear
keep ballot_circle_id
duplicates drop
drop if missing(ballot_circle_id)
ren ballot_circle_id circle_id
tempfile year1_ballot_circle_list
save `year1_ballot_circle_list'

* Save list of circles under litigation
insheet using "Data/Raw Data/Administrative Data/Circles under litigation.csv", comma clear
tempfile litigation
save `litigation'

* Save list of circles from baseline that are under litigation
insheet using "Data/Raw Data/Administrative Data/Circles under litigation.csv", comma clear
keep if inlist(fyear, 2013)
tempfile baselitigation
save `baselitigation'

* Load Baseline values (Q1 to Q4, 2013)
forval q = 1/`latest_qtr' { 
	local y = 2013 // Specifies year of baseline data
	
	* Handle special case: Circles 900300 & 900800 merged into 900310 between 2013 Q4 & Y1 ballot
	use "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Present - Analysis/2013_q4_crosswalk.dta", clear
	keep if inlist(circle_id, 900300, 900800)
	keep circle_id q`q'_2013_gross_dem* q`q'_2013_net_dem* q`q'_2013_recov_tot* q`q'_2012_recov_tot*
	collapse (sum) q`q'_2013_gross_dem* q`q'_2013_net_dem* q`q'_2013_recov_tot* q`q'_2012_recov_tot*
	gen circle_id = 900310
	tempfile overwrite
	save `overwrite'
	
	* Handle special case: Circle 900100 becomes 900101
	use "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Present - Analysis/2013_q4_crosswalk.dta", clear
	keep if inlist(circle_id, 900100)
	keep circle_id q`q'_2013_gross_dem* q`q'_2013_net_dem* q`q'_2013_recov_tot* q`q'_2012_recov_tot*
	replace circle_id = 900101
	tempfile overwrite2
	save `overwrite2'
	
	* Add revenue data for every circle in Y1 ballot list
	use `year1_ballot_circle_list', clear
	merge 1:1 circle_id using "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Present - Analysis/2014_q1_crosswalk.dta", keepusing(q`q'_`y'_* q`q'_2012_recov_tot*)
	drop if _merge == 2
	drop _merge
	merge 1:1 circle_id using "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Present - Analysis/2013_q4_crosswalk.dta", keepusing(q`q'_`y'_* q`q'_2012_recov_tot*) update
	drop if _merge == 2
	drop _merge
	
	* Add revenue data for special case2 above
	merge 1:1 circle_id using `overwrite', update
	drop _merge
	merge 1:1 circle_id using `overwrite2', update
	drop _merge
	
	rename q`q'_2012_recov_tot* pre_base_recov_tot*
	rename q`q'_`y'* base*
	
	* Sum current and arrears into total
	foreach var in gross_dem net_dem recov_tot {
		replace base_`var'_a = round(base_`var'_a)
		replace base_`var'_c = round(base_`var'_c)
		gen base_`var'_t = base_`var'_a + base_`var'_c
	}

	* Compute log of each variable
	foreach var in gross_dem net_dem recov_tot {
		foreach x in t c a {
			gen base_ln_`var'_`x' = log(base_`var'_`x')
		}
	}
	
	* Generate baseline log total recovery growth rate
	gen base_ln_recov_tot_t_growth = base_ln_recov_tot_t - log(pre_base_recov_tot_c + pre_base_recov_tot_a)
	gen base_ln_recov_tot_c_growth = base_ln_recov_tot_c - log(pre_base_recov_tot_c)
	gen base_ln_recov_tot_a_growth = base_ln_recov_tot_a - log(pre_base_recov_tot_a)

	drop pre_base*
	
	* Store baseline data in new file
	if `q' == 1 {
		gen qtr = `q'
		tempfile base
		save `base'
	}
	else { // Append to existing file if file already created
		gen qtr = `q'
		append using `base'
		save `base', replace
	}
}

* Load Current values (Q1 to Q4 2015)
local loop_count = 0
forval q = 1/`latest_qtr' {

	/*
	NOTE: 
		We use "TP Randomization" and NOT "TP Y2 Randomization" because analysis
		is done in terms of Y1 ballot circles, NOT Y2 ballot circles.
	*/
	use "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To TP Randomization/2015_q`q'", clear

	gen fyear = 2015
	gen qtr = `q'
	
	* Create file if it doesn't yet exist, append to existing if it does
	if `loop_count' == 0 {
		tempfile data
		save `data'
	}
	else {
		append using `data'
		save `data', replace
	}
	
	local loop_count = `loop_count' + 1
}

* Add recovery & exemption rates
foreach x in c a t {
	gen recoveryrate_`x' = recov_tot_`x' / net_dem_`x'
	gen nonexemptrate_`x' = net_dem_`x' / gross_dem_`x'
}

* Compute log of each variable
foreach var in gross_dem net_dem recov_tot recoveryrate nonexemptrate {
	foreach x in t c a {
		gen ln_`var'_`x' = log(`var'_`x')
	}
}

tempfile revenue_data
save `revenue_data'


****************************************************
* 2. Get crosswalked circle IDs (for treatment/HR data)
****************************************************

* Mapping of Y2 ballot circles to Y1 ballot circles
insheet using "Data/Raw Data/Administrative Data/120904 Crosswalk to Randomization_All.csv", comma clear
keep year2_ballot_circle_id ballot_circle_id
duplicates drop
drop if missing(ballot_circle_id)
ren year2_ballot_circle_id circle_id
ren ballot_circle_id year1_ballot_circle_id

tempfile y2_ballot_to_y1_ballot_mapping
save `y2_ballot_to_y1_ballot_mapping'

* Mapping of Q1 2015 (when HR defined) circles to Y1 ballot circles
insheet using "Data/Raw Data/Administrative Data/120904 Crosswalk to Randomization_All.csv", comma clear
keep q1_2015_circle_id ballot_circle_id
duplicates drop
drop if missing(ballot_circle_id)
ren q1_2015_circle_id circle_id
ren ballot_circle_id year1_ballot_circle_id

tempfile 2015q1_to_y1_ballot_mapping
save `2015q1_to_y1_ballot_mapping'


****************************************************
* 3. Load Y2 HR data
****************************************************

* Year 2 HR -- comes from Q1 2015 HR, who was there on August 5th
insheet using "Data/Raw Data/Current HR Confirmation/140915 HR Verification FY2015 Q1 - Ballot/150109 HR Verification Q1.csv", comma clear
keep if inspector == 1

keep circle_id ins? hr_id? ins_ac? start? end?
tostring start? end?, replace

reshape long ins hr_id ins_ac start end, i(circle_id) j(n)

drop if missing(hr_id) & ins == ""

replace start = "" if start == "."
replace end = "" if end == "."

replace start = "1.7.2014" if start == ""
replace end = "30.9.2014" if end == ""

foreach var of varlist start end {
	rename `var' `var'_temp
	gen `var' = date(`var'_temp, "DMY")
	drop `var'_temp
	format `var' %td
}

* Keep the person who was there on August 5th, 2014
keep if start <= mdy(8, 6, 2014)
keep if end > mdy(8, 6, 2014)

isid circle_id

merge 1:m circle_id using `2015q1_to_y1_ballot_mapping'
assert _merge != 2
drop if _merge == 1
drop _merge

drop circle_id
ren year1_ballot_circle_id circle_id

drop end

drop if inlist(hr_id, 11514, 23209) // TODO: why is this needed??

tempfile hr
save `hr'

****************************************************
* 4. Load Y2 randomization output and merge with HR
****************************************************

* Load 10 Lahore Pilot group from Year 1
clear
u "Data\Randomization\Output\Year 1/130726 Lahore PILOT Transfers Randomization Output 150"
keep if treatment == "PILOT GROUP"
gen circle_type = "Control"
keep partition_id division_name group circle_id circle_type stratum_id
gen new = 0
gen continuing = 0
tempfile lhr_pilot
sa `lhr_pilot'

* Load 10 Multan Pilot group from Year 1
u "Data\Randomization\Output\Year 1/130803 Multan PILOT Transfers Randomization Output 51135", clear
keep if treatment == "PILOT GROUP"
gen circle_type = "Control"
keep partition_id division_name group circle_id  circle_type stratum_id
gen new = 0
gen continuing = 0
tempfile multan_pilot
sa `multan_pilot'

* Load 285 Control circles without 69 new treatment circles
u "Data\Randomization\Output\Year 2/140830 Control Groups Year 2 Randomization 391", clear
drop if treatment==1
gen circle_type = "Control"
keep partition_id division_name group circle_id circle_type stratum_id
gen new = 0
gen continuing = 0
tempfile control
sa `control'

* Adding 72 Non-Continuing circles to control
u "Data\Randomization\Output\Year 2/140805 Treated Groups Year 2 Randomization 500060"
drop if treatment==1
gen circle_type = "Control"
keep partition_id division_name group circle_id  circle_type stratum_id
gen new = 0
gen continuing = 0
tempfile non_cont
sa `non_cont'

* Add treatment circles to list

u "Data\Randomization\Output\Year 2/140830 Control Groups Year 2 Randomization 391", clear
append using "Data\Randomization\Output\Year 2/140805 Treated Groups Year 2 Randomization 500060"
keep if treatment==1
replace details_treatment="New" if details_treatment=="control in year 1 & treatment in year 2" | details_treatment=="excl. in year 1 & treatment in year 2"
replace details_treatment="Continuing" if details_treatment=="dynamic incentives in year 1 & year 2" 
gen circle_type = "Treatment"
keep partition_id division_name group circle_id  circle_type ranking_method stratum_id details_treatment
gen new = details_treatment == "New"
gen continuing = details_treatment == "Continuing"
drop details_treatment
ren ranking_method scheme
/*
* Continuing variable wrongly assigned in these 6 cases, since this variable used outdated randomization file before
replace continuing = 0 	if inlist(circle_id, 101300, 109000, 400400, 402700, 1101300, 1106400)
replace new = 1 		if inlist(circle_id, 101300, 109000, 400400, 402700, 1101300, 1106400)
*/
* Compile into single file
append using `lhr_pilot'
append using `multan_pilot'
append using `control'
append using `non_cont'

isid circle_id

* Handle special cases
replace division_name = "LAHORE" if inlist(division_name, "LAHORE A", "LAHORE B")
gen temp = " "
egen group_name = concat(division_name temp group)
drop temp
replace group_name = "SARGODHA 3" if group_name=="SARGODHA 1" & circle_type=="Treatment"
tab group_name


************************************************************
* 5. Crosswalk circles to Y1 ballot & add analysis variables
************************************************************
/*
NOTE:
	Some circles are expressed in terms of Y2 ballot circle IDs. We ignore 
	circles from this group that were created after Y1 ballot.
*/

* Isolate the circles that need to be crosswalked
merge 1:1 circle_id using `year1_ballot_circle_list'
drop if _merge == 2
gen tocrosswalk = _merge == 1
drop _merge

* Merge only on circles that need to be crosswalked
preserve
	keep if tocrosswalk == 1
	merge 1:m circle_id using `y2_ballot_to_y1_ballot_mapping'
	drop if _merge == 1 // Drop if circle created after y1 ballot
	drop if _merge == 2 // Drop if circle not in list of crosswalked circles
	drop _merge
	drop circle_id
	ren year1_ballot_circle_id circle_id

	tempfile updated
	save `updated'
restore

* Drop if crosswalked
drop if tocrosswalk == 1
append using `updated'
duplicates drop
drop tocrosswalk

isid circle_id

* Remove columns and create required analysis variables
gen DEM_sel = scheme == "DEMAND"
gen REV_sel = scheme == "RECOVERY"
drop scheme
tab stratum_id, generate(stratdum)
drop stratum_id
gen treatment = DEM_sel + REV_sel
ren new new_sel
ren continuing cont_sel


****************************************************
* 6. Merge Treatment, HR, revenue, & implement data
****************************************************

* Merge circle IDs with HR data
merge 1:m circle_id using `hr'
drop if _m == 2
keep circle_id group_name group stratdum* DEM_sel REV_sel new_sel cont_sel hr_id treatment part* division
egen group_id = group(group_name)

duplicates drop circle_id, force // OK to do this, since we aren't using HR IDs for analysis

sa "TP Analysis/Coded Data/150610 Y2 Treatment Data", replace

* Merge treatment/HR data with revenue data
use `revenue_data', clear	
merge m:1 circle_id using "TP Analysis/Coded Data/150610 Y2 Treatment Data"
drop if _m == 1 // Merge fails for Y2 ballot circles not included in Y1 ballot
drop _merge

* Make sure that we match with the year 2 ballot circle IDs
merge m:1 circle_id using `year1_ballot_circle_list'
drop if _m == 2 // Merge fails for Y2 ballot circles not included in Y1 ballot
drop _m

* Add baseline values
merge 1:1 circle_id qtr using `base'
drop if _m == 2 // Merge fails for Y2 ballot circles not included in Y1 ballot
drop _m

* Create implement variable
merge 1:1 circle_id qtr using "TP Analysis/Coded Data/Implement Y2"
drop if _merge == 2 // Drop circle 1104400 -- circle is under litigation, but an inspector transferred to it
foreach var of varlist REV_impl DEM_impl treat_impl {
	replace `var' = 0 if _merge == 1
}
drop _merge

* Sanity check that missing values are only for litigated circles
merge 1:1 circle_id fyear qtr using `litigation'
drop if _merge == 2
assert _merge == 3 if recov_tot_t == .
drop _merge

* Label treatment variables
label var treatment "Treatment"
label var DEM_sel "Demand"
label var REV_sel "Revenue"
label var new_sel "New"
label var cont_sel "Continuing"
label var DEM_impl "Demand"
label var REV_impl "Revenue"

save "TP Analysis/Coded Data/TP Y2 Analysis Data", replace

****************************************************
* 7. Create separate dataset w Y1 treatment status
****************************************************

* Y1 complete analysis data, collapsed by circle IDs
use "TP Analysis/Coded Data/150525 TP Analysis Data", clear
collapse DEM_sel REV_sel treatment, by(circle_id)
assert inlist(DEM_sel, 0, 1) & inlist(REV_sel, 0, 1) & inlist(treatment, 0, 1) // Ensure that collapsed circle IDs have same treatment dummy value

* Assign clearer names to Y1 treatment variables
rename DEM_sel DEM_sel_y1
rename REV_sel REV_sel_y1
rename treatment treatment_y1
duplicates drop

* Merge with Y2 Analysis Data
merge 1:m circle_id using "TP Analysis/Coded Data/TP Y2 Analysis Data" // Unmerged values were not included in Y1 ballot
drop _m

* Create control & interaction variables
gen control = !treatment
gen control_y1 = !treatment_y1 if !missing(treatment_y1)
gen y1_treat_y2_treat = treatment_y1 * treatment
gen y1_contr_y2_treat = control_y1 * treatment
gen y1_treat_y2_contr = treatment_y1 * control

* Label variables
label var y1_treat_y2_treat "Year 1 Treatment * Year 2 Treatment"
label var y1_contr_y2_treat "Year 1 Control * Year 2 Treatment"
label var y1_treat_y2_contr "Year 1 Treatment * Year 2 Control"

* Check that new vs continuing assignment matches interaction variables
preserve
	duplicates drop circle_id, force
	keep circle_id REV_sel DEM_sel treatment treatment_y1 REV_sel_y1 DEM_sel_y1 new_sel cont_sel division
	gen new_dummy = inlist(treatment_y1, 0, .) & treatment == 1 
	gen cont_dummy = treatment_y1 == 1 & treatment == 1 
	gen new_dummy_mismatch = new_dummy != new_sel 
	gen cont_dummy_mismatch = cont_dummy != cont_sel
	gen mismatch = new_dummy_mismatch | cont_dummy_mismatch
	
	assert mismatch == 0
restore

* Save data:
save "TP Analysis/Coded Data/TP Y2 Analysis Data w Y1 Treatment", replace
