/*
Creates histograms using competitiveness simulations (based on baseline preferences)

Author:
	Ismail Khan (2015-)
	
Date created:
	December 3, 2015
	
Summary:
	- For each inspector, across simulations, we draw histograms of the following:
		Fraction of outcomes where first choice is granted
		Fraction of outcomes where outcome is better than status quo
		Fraction of outcomes where outcome is equal to status quo
		Fraction of outcomes where outcome is worse than status quo
		Std deviation of rank of outcomes
		Mean of rank of outcomes

Notes:
	- Use "Run" or Cmd-R or Ctrl-R instead of "Do" for easier-to-parse output
	
*/

******************************************************************************
* Initial setup
******************************************************************************

clear all
set more off
pause on
set maxvar 20000
cap cd "$PAKTAX2_ANALYSIS"

* Declare input files
local posting_simulation = 			"TP Analysis/Coded Data/Posting simulation"
local base_simulation_prefs = 		"TP Analysis/Coded Data/Cleaned baseline preferences for simulation OLD"

* Declare output files
local output_folder = 				"TP Analysis/Coded Data"
local output_file = 				"`output_folder'/Basic simulation results"


******************************************************************************
* Get rank of current circle
******************************************************************************

use "`base_simulation_prefs'", clear // Note that this file has missing ranks randomly generated

keep if own_circle == 1
keep partition_name group hr_id circle_id norm_ranking
ren (circle_id norm_ranking) (own_circle_id ranking)

bys partition_name group hr_id: gen j = _n
assert j <= 2
reshape wide own_circle_id ranking, i(partition_name group hr_id) j(j) // Required because some inspectors have two circles within 1 group

tempfile current_circle_rank
sa `current_circle_rank'


******************************************************************************
* Generate analysis variables
******************************************************************************

use "`posting_simulation'", clear
merge 1:1 partition_name group hr_id using `current_circle_rank', assert(match) nogen

forval i=1/1000 {

	* Top choice granted
	gen top_choice_granted`i' = posting_circle_rank`i' == 1
	
	* Outcome is weakly better than status quo
	gen move_up_weak`i' = posting_circle_rank`i' <= ranking1 if mi(ranking2)
	replace move_up_weak`i' = posting_circle_rank`i' <= ranking1 & posting_circle_rank`i' <= ranking2 if !mi(ranking2)
	
	* Outcome is strictly better than status quo
	gen move_up_strict`i' = posting_circle_rank`i' < ranking1 if mi(ranking2)
	replace move_up_strict`i' = posting_circle_rank`i' < ranking1 & posting_circle_rank`i' < ranking2 if !mi(ranking2)	
	
	* Outcome is weakly worse than status quo
	gen move_down_weak`i' = posting_circle_rank`i' >= ranking1 if mi(ranking2)
	replace move_down_weak`i' = posting_circle_rank`i' >= ranking1 & posting_circle_rank`i' >= ranking2 if !mi(ranking2)
	
	* Outcome is strictly worse than status quo
	gen move_down_strict`i' = posting_circle_rank`i' > ranking1 if mi(ranking2)
	replace move_down_strict`i' = posting_circle_rank`i' > ranking1 & posting_circle_rank`i' > ranking2 if !mi(ranking2)	
	
	* Outcome is one of the status quo circles
	gen no_move`i' = posting_circle_rank`i' == ranking1 if mi(ranking2)
	replace no_move`i' = posting_circle_rank`i' == ranking1 | posting_circle_rank`i' == ranking2 if !mi(ranking2)
}

* Fraction of outcomes where first choice is granted
egen fraction_first_choice = rowtotal(top_choice_granted*)
replace fraction_first_choice = fraction_first_choice / 1000

* Fraction of outcomes where outcome is weakly better than status quo
egen fraction_better_weak = rowtotal(move_up_weak*)
replace fraction_better_weak = fraction_better_weak / 1000

* Fraction of outcomes where outcome is strictly better than status quo
egen fraction_better_strict = rowtotal(move_up_strict*)
replace fraction_better_strict = fraction_better_strict / 1000

* Fraction of outcomes where outcome is weakly worse than status quo
egen fraction_worse_weak = rowtotal(move_down_weak*)
replace fraction_worse_weak = fraction_worse_weak / 1000

* Fraction of outcomes where outcome is strictly worse than status quo
egen fraction_worse_strict = rowtotal(move_down_strict*)
replace fraction_worse_strict = fraction_worse_strict / 1000

* Fraction of outcomes where outcome is same as status quo
egen fraction_same = rowtotal(no_move*)
replace fraction_same = fraction_same / 1000

* Std deviation and mean of rank of outcomes
egen outcome_stdev = rowsd(posting_circle_rank*)
egen outcome_mean = rowsd(posting_circle_rank*)

drop posting_circle_rank* move_up* move_down* no_move* top_choice_granted*

* Label variables
label var outcome_stdev	"Outcome standard deviation"
label var outcome_stdev "Outcome stdev"
label var outcome_mean "Outcome mean"
label var fraction_better_weak "Fraction weakly better"
label var fraction_better_strict "Fraction strictly better"
label var fraction_worse_weak "Fraction weakly worse"
label var fraction_worse_strict "Fraction strictly worse"
label var fraction_first_choice "Fraction first choice"

sa "`output_file'", replace
