/*
Incentives for treatment vs control inspectors

Author(s):
	Ismail Khan (2015-)

Summary:
	In this file we calculate the following:
		- Dummy for if an inspector moved at all between baseline and Y2 Q3
		- Dummy for if an inspector stayed in the baseline circle until Y2 Q3
	
Notes:
	We record inspector postings at the following times:
		- Baseline
		- End of Y2 Q3 (presumably once all transfers were completed)
	
Date created:
	Mar 1, 2016
*/


*************************************************************
* Initial Setup
*************************************************************

clear all
set more off
cap cd "$PAKTAX2_ANALYSIS"

* Declare input files here
local base_simulation_prefs = 		"TP Analysis/Coded Data/Cleaned baseline preferences for simulation OLD.dta" 
local base_prefs = 					"TP Analysis/Coded Data/Cleaned baseline preferences.dta"
local hr_q3_2015_file = 			"Data/Raw Data/Current HR Confirmation/150301 HR Verification FY2015 Q3/150512 HR Verification Q3.csv"
local crosswalk_file = 				"Data/Raw Data/Administrative Data/120904 Crosswalk to Randomization_All.csv"
local y2_analysis_file = 			"TP Analysis/Coded Data/TP Y2 Analysis Data"
local y1_analysis_file = 			"TP Analysis/Coded Data/150525 TP Analysis Data"

* Declare output files here
local y1_movement_file = 			"TP Analysis/Coded Data/Y1 Movement Dummies"


*************************************************************
* Get Y1 Ballot HR
*************************************************************

use "`base_prefs'", clear
keep if own_circle == 1
keep partition_name group hr_id circle_id
drop if mi(hr_id)
duplicates drop

tempfile y1_ballot_hr
sa `y1_ballot_hr'

*************************************************************
* Get Treatment Status
*************************************************************

use "`y2_analysis_file'", clear
keep circle_id treatment
ren treatment treatment_y2
duplicates drop

tempfile y2_treat_status
sa `y2_treat_status'

use "`y1_analysis_file'", clear
keep circle_id treatment
ren treatment treatment_y1
duplicates drop

tempfile y1_treat_status
sa `y1_treat_status'


*************************************************************
* Mapping of circles to Y1 ballot circles
*************************************************************

insheet using "`crosswalk_file'", comma clear
keep q3_2015_circle_id ballot_circle_id
duplicates drop
drop if missing(ballot_circle_id)
ren q3_2015_circle_id circle_id
ren ballot_circle_id year1_ballot_circle_id
tempfile 2015q3_to_y1_ballot_mapping
save `2015q3_to_y1_ballot_mapping'

insheet using "`crosswalk_file'", comma clear
keep ballot_circle_id
duplicates drop
drop if missing(ballot_circle_id)
ren ballot_circle_id circle_id
tempfile y1_ballot_circles
save `y1_ballot_circles'


*************************************************************
* Get mapping of circles to groups
*************************************************************

use "`y2_analysis_file'", clear
keep circle_id partition_id group
duplicates drop
decode partition_id, gen(partition_name)
drop partition_id

tempfile circle_group_mapping
sa `circle_group_mapping'


*************************************************************
* Prepare baseline preferences
*************************************************************

* Can pull balloted HR from baseline preferences
use "`base_prefs'", clear
drop norm_ranking u1

* Normalize all rankings
bys partition_name group hr_id: egen rank_count = count(ranking)
bys partition_name group hr_id: egen max_rank = max(ranking)
assert max_rank == rank_count if rank_count > 0
gen norm_ranking = 1 + ( ((ranking-1)/(rank_count-1)) * (10-1) ) if rank_count > 0
drop rank_count max_rank

* Drop missing rankings
bys partition_name group hr_id: gen missing_ranking = mi(ranking)
bys partition_name group hr_id: egen any_missing_ranking = max(missing_ranking)
drop if any_missing_ranking
assert !mi(ranking)
drop any_missing_ranking missing_ranking

isid partition_name group hr_id circle_id

tempfile base_preferences
sa `base_preferences'


*************************************************************
* Get inspectors for each circle at end of Y2 Q3
*************************************************************

insheet using "`hr_q3_2015_file'", comma clear

/*
Apply basic data cleaning
*/
keep if inspector == 1
drop if mi(circle_id)
isid circle_id

* Ensure that hr ID is not missing if circle is not vacant
assert !mi(hr_id1) if ins1 != "" & ins1 != "VACANT"
assert !mi(hr_id2) if ins2 != "" & ins2 != "VACANT"
assert !mi(hr_id3) if ins3 != "" & ins3 != "VACANT"

* Convert start* and end* to string vars
tostring start*, replace
tostring end*, replace
replace start1 = "" if mi(start1) | start1 == "."
replace start2 = "" if mi(start2) | start2 == "."
replace start3 = "" if mi(start3) | start3 == "."
replace end1 = "" if mi(end1) | end1 == "."
replace end2 = "" if mi(end2) | end2 == "."
replace end3 = "" if mi(end3) | end3 == "."

* Remove inspectors that left their circle
reshape long hr_id ins ins_ac start end, i(circle_id) j(j)
drop if !mi(end) | mi(hr_id)
keep circle_id hr_id 
isid circle_id

/*
* Crosswalk circle IDs to Y1 ballot
* 
* _m == 1 for circles that were created after Y1 ballot
* _m == 2 for circles that were vacant at end of Y2 Q3
*/
merge 1:m circle_id using `2015q3_to_y1_ballot_mapping', keep(match) nogen
replace circle_id = year1_ballot_circle_id
drop year1_ballot_circle_id
duplicates drop

/*
* Link circle IDs to groups
* 
* _m == 1 for litigated circles
* _m == 2 for circles that were vacant at end of Y2 Q3
*/
merge m:1 circle_id using `circle_group_mapping', keep(match) nogen

tempfile end_of_y2_q3_hr_long
sa `end_of_y2_q3_hr_long'

bys partition_name group circle_id: gen j = _n
reshape wide hr_id, i(partition_name group circle_id) j(j)

tempfile end_of_y2_q3_hr
sa `end_of_y2_q3_hr'


*************************************************************
* Get preference ranking of inspector's Y2 Q3 circle
*************************************************************

use `end_of_y2_q3_hr_long', clear

merge 1:1 partition_name group hr_id circle_id using `base_preferences', keep(match) keepusing(norm_ranking) nogen
bys partition_name group hr_id: gen j = _n
assert j <= 2
reshape wide circle_id norm_ranking, i(partition_name group hr_id) j(j)
egen y2q3_best_ranking = rowmin(norm_ranking1 norm_ranking2) // Only keep best circle ranking within group
egen y2q3_worst_ranking = rowmax(norm_ranking1 norm_ranking2) // Only keep worst circle ranking within group
ren circle_id* y2q3_circle_id*
drop norm_ranking*

isid partition_name group hr_id

tempfile y2q3_ranks
sa `y2q3_ranks'


*************************************************************
* Get preference ranking of inspector's baseline circle
*************************************************************

use `base_preferences', clear

keep if own_circle == 1
keep partition_name group hr_id circle_id norm_ranking
bys partition_name group hr_id: gen j = _n
assert j <= 2
reshape wide circle_id norm_ranking, i(partition_name group hr_id) j(j)
egen baseline_best_ranking = rowmin(norm_ranking1 norm_ranking2) // Only keep best circle ranking within group
egen baseline_worst_ranking = rowmax(norm_ranking1 norm_ranking2) // Only keep worst circle ranking within group
drop norm_ranking* circle_id*

isid partition_name group hr_id

tempfile baseline_ranks
sa `baseline_ranks'


*************************************************************
* Calculate value of better/worse dummies
*************************************************************

* Merge baseline ranks with Y2 Q3 ranks
use `baseline_ranks', clear
merge 1:1 partition_name group hr_id using `y2q3_ranks', assert(1 3) keep(match) nogen

* Generate dummies
gen strictly_better_dummy = y2q3_best_ranking < baseline_best_ranking // lower ranking means one is better off
gen strictly_worse_dummy = y2q3_best_ranking > baseline_worst_ranking

label var strictly_better_dummy 	"Strictly Better Off"
label var strictly_worse_dummy 		"Strictly Worse Off"

* Save
tempfile better_worse_dummies
sa `better_worse_dummies'


*************************************************************
* Merge data to see if "any move" has taken place
*************************************************************

use `end_of_y2_q3_hr', clear

* Add ANY MOVE dummies
merge 1:1 circle_id using `y1_ballot_hr', keep(2 3) nogen // _m == 2: vacant in Y2 Q3; _m == 1: circle not in baseline
ren hr_id base_hr_id
ren hr_id* y1_end_hr_id*
gen no_move = inlist(base_hr_id, y1_end_hr_id1, y1_end_hr_id2, y1_end_hr_id3)
gen any_move = !inlist(base_hr_id, y1_end_hr_id1, y1_end_hr_id2, y1_end_hr_id3)
drop *hr_id*
label var no_move 	"No move dummy"
label var any_move 	"Any move dummy"

* Add group IDs
merge 1:1 circle_id using `circle_group_mapping', assert(2 3) keep(match) nogen

/*
* Assign Y1 ballot HR
* 
* _m == 1 for circles with no inspector
* _m == 2 for litigated circles
* _m == 3 for treatment inspectors still in department
*/
merge 1:1 circle_id using `y1_ballot_hr', keep(match) keepusing(hr_id) nogen

/*
* Add dummies
* 
* _m == 1 for circles where we do not have a Y2 Q3 circle in which to rank inspector
* _m == 2 for litigated circles
* _m == 3 for treatment inspectors still in department
*/
merge m:1 partition_name group hr_id using `better_worse_dummies', assert(1 3) nogen

* Change in preference status
gen preference_change_direction = 0 if !mi(strictly_better_dummy, strictly_worse_dummy)
replace preference_change_direction = 1 if strictly_better_dummy == 1
replace preference_change_direction = -1 if strictly_worse_dummy == 1

label var preference_change_direction "Direction of change in preference"

* Add continuing dummy and treatment status
merge 1:1 circle_id using `y1_treat_status', keep(match) keepusing(treatment_y1) nogen
merge 1:1 circle_id using `y2_treat_status', keep(match) keepusing(treatment_y2) nogen
gen continuing = treatment_y1 & treatment_y2
label var treatment_y1 "Y1 Treatment"
label var treatment_y2 "Y2 Treatment"
label var continuing "Continuing treatment"

sa "`y1_movement_file'", replace

