/*
Prepares dataset for use in Y1 preferences regressions

Authors:
	Ismail Khan (2015-)

Date created:
	October 29, 2015
	
Notes:
	List of desired dependent variables:
		move_up_base
		move_down_base
		move_up_y1
		move_down_y1
		any_move
		top_choice_same
		rank_corr

	Other variables to be added:
		continuing
		groupdum
	
Special note on inspector 40838
	Inspector 40838 was believed to be in 402700 at the time of baseline, so 402700 was 
	included in GUJRANWALA group 5. However, inspector 40838 was actually in 402800 at
	the time. We thus have 40838's preferences, but for the wrong group (402700 instead
	of 402800). We ignore both 402700 and 402800 when computing own circle rank, but we
	use 402700's preference to compute average circle rank. We also only use 402800 when
	calculating avg circle rank.
	
*/

* Initial setup
clear all
set more off
pause on
cap cd "$PAKTAX2_ANALYSIS"

******************************************************************************
* Initial preparation of data
******************************************************************************

* Load list of pilot circles
use "Data\Randomization\Output\Year 1/130803 Multan PILOT Transfers Randomization Output MERGE 51135.dta", clear
append using "Data\Randomization\Output\Year 1/130726 Lahore PILOT Transfers Randomization Output MERGE 150.dta"
keep circle_id
isid circle_id
tempfile pilot_circles
sa `pilot_circles'

* Load treatment list for Year 1
use "TP Analysis/Coded Data/Randomization Year 1", clear
keep circle_id hr_id
gen treatment_y1 = 1
merge 1:1 circle_id using `pilot_circles', keep(1) nogen // Remove circles used in pilot
keep hr_id treatment_y1
isid hr_id
tempfile y1_treat_inspectors
sa `y1_treat_inspectors'

* Add year 2 treatment status
use "Data/Randomization\Ballot Cleaning Year 2\Output/150622 Complete Treatment List Year 2.dta", clear
keep hr_id
duplicates drop
gen treatment_y2 = 1
merge m:1 hr_id using `y1_treat_inspectors', keep(2 3) nogen
replace treatment_y2 = 0 if mi(treatment_y2)
replace treatment_y1 = 0 if mi(treatment_y1)
gen continuing = treatment_y2 & treatment_y1
sa `y1_treat_inspectors', replace

* Need to crosswalk transfer table circle IDs
insheet using "Data/Raw Data/Administrative Data/120904 Crosswalk to Randomization_All.csv", comma clear
keep ballot_circle_id
duplicates drop
drop if mi(ballot_circle_id)
tempfile ballot_circle_ids
sa `ballot_circle_ids', replace

******************************************************************************
* Load and compile preference data
******************************************************************************

clear all

* List of files in directory
local pref_files : dir "Data\Raw Data/Preference Tracking/Data/" files "*.xlsx"

* Create empty file for Y1 preferences
tempfile y1_preferences
save `y1_preferences', emptyok

* Append all files in directory
foreach file in `pref_files' { 
	import excel using "Data\Raw Data/Preference Tracking/Data/`file'", firstrow clear
	destring own_circle, replace // is string in some files, byte in others
	append using `y1_preferences'
	sa `y1_preferences', replace
}
ren K comments

* Create accurate group IDs
replace division_name = "LAHORE" if inlist(division_name, "LAHORE A", "LAHORE B")
egen group_id = group(division_name group)

* Ensure rankings make sense
bys own_hr_id: egen rank_sum = total(ranking)
bys own_hr_id: egen rank_count = count(ranking)
assert rank_sum == (rank_count * (rank_count + 1))/2 if rank_count > 0
drop rank_sum rank_count

* Normalize all rankings
bys own_hr_id: egen rank_count = count(ranking)
bys own_hr_id: egen max_rank = max(ranking)
assert max_rank == rank_count if rank_count > 0
replace ranking = 1 + ( ((ranking-1)/(rank_count-1)) * (10-1) ) if rank_count > 0
drop rank_count max_rank

sa `y1_preferences', replace

* Load Baseline preference data for treatment inspectors
use "TP Analysis/Coded Data/Treatment Baseline Preferences for Analysis complete OLD", clear
merge m:1 circle_id using `pilot_circles' // Remove pilot circles
keep if _m == 1
drop _m
ren hr_id own_hr_id
drop if mi(own_hr_id)
drop if own_hr_id==11507 & group==4 // additional charge
drop if own_hr_id==40962 & group==1

* Ensure rankings make sense
bys own_hr_id group: egen rank_sum = total(ranking)
bys own_hr_id group: egen rank_count = count(ranking)
assert rank_sum == (rank_count * (rank_count + 1))/2 if rank_count > 0
drop rank_sum rank_count

* Normalize all rankings
bys own_hr_id group: egen rank_count = count(ranking)
bys own_hr_id group: egen max_rank = max(ranking)
assert max_rank == rank_count if rank_count > 0
replace ranking = 1 + ( ((ranking-1)/(rank_count-1)) * (10-1) ) if rank_count > 0
drop rank_count max_rank

tempfile base_preferences
sa `base_preferences'

******************************************************************************
* Load and compile transfer tables
******************************************************************************

clear all

* List of files in directory
local pref_files : dir "Data/Raw Data/FY 14 Transfers/Transfer Tables FULL/" files "140823*.xlsx"

* Create empty file for Y1 preferences
tempfile transfer_table
save `transfer_table', emptyok

* Append all files in directory
foreach file in `pref_files' { 
	import excel using "Data/Raw Data/FY 14 Transfers/Transfer Tables FULL/`file'", firstrow clear
	append using `transfer_table'
	sa `transfer_table', replace
}

save "TP Analysis\Coded Data/transfer_file", replace
 
keep HRID CurrentCircle NewCircle
ren (HRID CurrentCircle NewCircle) (hr_id current_circle_id new_circle_id)

sa `transfer_table', replace

* Identify current circles that need to be crosswalked
use `ballot_circle_ids', clear
ren ballot_circle_id current_circle_id
merge 1:m current_circle using `transfer_table', keep(2 3)
gen current_circle_crosswalked = (_m == 2) if !mi(current_circle_id)
drop _m
sa `transfer_table', replace

* Identify new circles that need to be crosswalked (none, it turns out!)
use `ballot_circle_ids', clear
ren ballot_circle_id new_circle_id
merge 1:m new_circle_id using `transfer_table', keep(2 3)
gen new_circle_crosswalked = (_m == 2) if !mi(new_circle_id)
drop _m

* Manually crosswalk current circles
replace current_circle_id = 507201 if current_circle_id == 507300
replace current_circle_id = 613610 if current_circle_id == 613630
replace current_circle_id = 614300 if current_circle_id == 614310
replace current_circle_id = 807101 if current_circle_id == 807103
replace current_circle_id = 807102 if current_circle_id == 807104
replace current_circle_id = . 	   if current_circle_id == 907900
drop *crosswalked

/*
* Manually change current_circle_id when necessary // using data from Pakistan Property Tax Project 2\Data\Raw Data\Current HR Confirmation\140630 HR Verification FY2014 Q4/150109 HR Verification Q4
replace current_circle_id=109000 if hr_id==11671 & current_circle_id==107500
*replace current_circle_id= if hr_id==11658 & current_circle_id==107800 
*replace current_circle_id= if hr_id==11660 & current_circle_id==108000 // remains in control circle only
*replace current_circle_id= if hr_id==11509 & current_circle_id==205600 // he went from 203300 to 205600 during Y1Q4
*replace current_circle_id= if hr_id==31202 & current_circle_id==306300 // in both 306300 & 306400 but both control circles
*replace current_circle_id= if hr_id==31254 & current_circle_id==306500
*replace current_circle_id= if hr_id==60195 & current_circle_id==400400
*replace current_circle_id= if hr_id==40838 & current_circle_id==402800
*replace current_circle_id= if hr_id==60130 & current_circle_id==609600
*replace current_circle_id= if hr_id==61000 & current_circle_id==609700
replace current_circle_id=610800 if hr_id==60125 & current_circle_id==611900 // he also stayed in treatment circle
*replace current_circle_id= if hr_id==60162 & current_circle_id==613100
*replace current_circle_id= if hr_id==60233 & current_circle_id==613610
*replace current_circle_id= if hr_id==60196 & current_circle_id==614100
*replace current_circle_id= if hr_id==40843 & current_circle_id==614600
*replace current_circle_id= if hr_id==60248 & current_circle_id==902903
*replace current_circle_id= if hr_id==92027 & current_circle_id==903200
*replace current_circle_id= if hr_id==92302 & current_circle_id==905100
*replace current_circle_id= if hr_id==92205 & current_circle_id==909500
*replace current_circle_id= if hr_id==61005 & current_circle_id==1000800
*replace current_circle_id= if hr_id==112702 & current_circle_id==1106100
*/

sa `transfer_table', replace


******************************************************************************
* Add rank of new and current circle using baseline preferences
******************************************************************************

* Ranking for current circle
use `base_preferences', clear
drop if mi(ranking)
duplicates drop

* Count the number of distinct inspectors in each group
preserve
	keep partition_name group own_hr_id
	duplicates drop
	collapse (count) own_hr_id, by(partition_name group)
	ren own_hr_id num_ins_in_group
	tempfile num_ins_per_group
	sa `num_ins_per_group', replace
restore
merge m:1 partition_name group using `num_ins_per_group', assert(match) keepusing(num_ins_in_group) nogen

* Calculate u1
bys partition_name group own_hr_id (ranking): gen simple_rank = _n
gen u1 = 1 - ( (simple_rank-1) / (num_ins_in_group - 1) )
replace u1 = 0 if u1 < 0

keep own_hr_id circle_id ranking u1
duplicates drop
ren own_hr_id hr_id
ren ranking base_current_ranking
ren circle_id current_circle_id
ren u1 base_current_u1

merge 1:1 current_circle_id hr_id using `transfer_table', keep(2 3) nogen

tempfile pref_analysis_data
sa `pref_analysis_data'

* Ranking for new circle
use `base_preferences', clear
keep own_hr_id circle_id ranking
drop if mi(ranking)
duplicates drop
ren own_hr_id hr_id
ren ranking base_new_ranking
ren circle_id new_circle_id

merge 1:1 new_circle_id hr_id using `pref_analysis_data', keep(2 3) nogen

tempfile pref_analysis_data
sa `pref_analysis_data'


******************************************************************************
* Add rank of new and current circle using y1 preferences (also calculate u1 of current)
******************************************************************************

* Ranking for current circle
use `y1_preferences', clear

drop if mi(ranking)
duplicates drop

* Count the number of distinct inspectors in each group
preserve
	keep division_name group_id own_hr_id
	duplicates drop
	collapse (count) own_hr_id, by(division_name group_id)
	ren own_hr_id num_ins_in_group
	tempfile num_ins_per_group
	sa `num_ins_per_group', replace
restore
merge m:1 division_name group_id using `num_ins_per_group', assert(match) keepusing(num_ins_in_group) nogen

* Calculate u1
bys division_name group own_hr_id (ranking): gen simple_rank = _n
gen u1 = 1 - ( (simple_rank-1) / (num_ins_in_group - 1) )
replace u1 = 0 if u1 < 0

keep own_hr_id circle_id ranking u1
duplicates drop
ren own_hr_id hr_id
ren ranking y1_current_ranking
ren circle_id current_circle_id
ren u1 y1_current_u1

merge 1:1 current_circle_id hr_id using `pref_analysis_data', keep(2 3) nogen

sa `pref_analysis_data', replace

* Ranking for new circle
use `y1_preferences', clear
keep own_hr_id circle_id ranking
drop if mi(ranking)
duplicates drop
ren own_hr_id hr_id
ren ranking y1_new_ranking
ren circle_id new_circle_id

merge 1:1 new_circle_id hr_id using `pref_analysis_data', keep(2 3) nogen

sa `pref_analysis_data', replace


******************************************************************************
* Figure out the top choice for each inspectors, and add to analysis dataset
******************************************************************************

use `y1_preferences', clear
keep if ranking == 1
duplicates drop
keep own_hr_id circle_id
ren own_hr_id hr_id
ren circle_id y1_top_choice

merge 1:1 hr_id using `pref_analysis_data', assert(2 3) nogen
sa `pref_analysis_data', replace

use `base_preferences', clear
keep if ranking == 1
duplicates drop

ren own_hr_id hr_id
ren circle_id base_top_choice

merge 1:1 hr_id using `pref_analysis_data', assert(2 3) nogen
sa `pref_analysis_data', replace


******************************************************************************
* Calculate rank correlation 
******************************************************************************

* First, put rankings side by side
use `y1_preferences', clear
keep own_hr_id circle_id ranking
drop if mi(ranking)
ren ranking y1_ranking
ren own_hr_id hr_id
drop if circle_id == 402800 // see notes in header for why we need to do this
tempfile y1_preferences_concise
sa `y1_preferences_concise'

use `base_preferences', clear
keep own_hr_id circle_id ranking
drop if mi(ranking)
ren ranking base_ranking
ren own_hr_id hr_id
drop if circle_id == 402700 // see notes in header for why we need to do this
merge 1:1 hr_id circle_id using `y1_preferences_concise', keep(match) nogen

* Second, compute spearman's rho
statsby rank_corr = r(rho), by(hr_id) clear : spearman y1_ranking base_ranking

* Lastly, save
merge 1:1 hr_id using `pref_analysis_data', assert(2 3) nogen
sa `pref_analysis_data', replace


******************************************************************************
* Create group identifier
******************************************************************************

use `y1_preferences', clear

* Drop cases where inspector has missing preferences, when he already has preferences for another group.
bys own_hr_id group_id: egen num_not_missing = count(ranking)
bys own_hr_id group_id: gen any_missing = num_not_missing != _N
keep own_hr_id group_id any_missing
duplicates drop
bys own_hr_id: drop if any_missing & _N > 1

ren own_hr_id hr_id
isid hr_id

merge 1:1 hr_id using `pref_analysis_data', assert(2 3) nogen
assert !mi(group_id)
sa `pref_analysis_data', replace


******************************************************************************
* Generate analysis variables
******************************************************************************

use `pref_analysis_data', clear

gen move_up_base = 				base_new_ranking < base_current_ranking 	if !mi(base_new_ranking) & !mi(base_current_ranking)
gen move_down_base = 			base_new_ranking > base_current_ranking		if !mi(base_new_ranking) & !mi(base_current_ranking)
gen move_up_y1 = 				y1_new_ranking < y1_current_ranking			if !mi(y1_new_ranking) & !mi(y1_current_ranking)
gen move_down_y1 = 				y1_new_ranking > y1_current_ranking			if !mi(y1_new_ranking) & !mi(y1_current_ranking)
gen any_move =					new_circle_id != current_circle_id			if !mi(new_circle_id)
gen own_circle_favorite = 		y1_current_ranking == 1						if !mi(y1_current_ranking)
gen own_circle_favorite_base = 	base_current_ranking == 1					if !mi(base_current_ranking)
gen own_circle_rank = 			y1_current_ranking							if !mi(y1_current_ranking)			
gen own_circle_rank_base = 		base_current_ranking						if !mi(base_current_ranking)
gen own_circle_u1 = 			y1_current_u1								if !mi(y1_current_u1)			
gen own_circle_u1_base = 		base_current_u1								if !mi(base_current_u1)

* Add continuing variable
merge 1:1 hr_id using `y1_treat_inspectors', assert(match) nogen

* Label dependent variables
label var continuing 				"Continuing"
label var own_circle_rank_base 		"Own circle rank, baseline"
label var own_circle_favorite_base 	"Own circle is favorite, baseline"
label var own_circle_u1 			"Own circle u1"
label var own_circle_u1_base 		"Own circle u1, baseline"

* Add: is first choice the same in Y1 and base?
gen top_choice_same = base_top_choice == y1_top_choice if !mi(base_top_choice) & !mi(y1_top_choice)

sa `pref_analysis_data', replace


******************************************************************************
* 8. Save analysis datasets
******************************************************************************

use `pref_analysis_data', replace
save "TP Analysis/Coded Data/Y1 Preferences analysis data", replace


