/*
Summary stats

Author(s):
	Ismail Khan (2015-)

Summary:
	Table of summary statistics from admin data
	
Date created:
	Mar 20, 2016
*/


********************************************************************************
* Initial Setup
********************************************************************************

clear all
set more off
set matsize 10000

cap cd "${TP_ANALYSIS}"
do "Do Files/programs/all_programs.do"

* Declare input files here
local analysis_file = 			"Coded Data/TP Y2 Analysis Data w Y1 Treatment"
local python_file = 			"Do Files/Paper/clean_summary_stats.py"

********************************************************************************
* Draw Table
********************************************************************************

/* Admin Data */

# delimit ;
local vars 
	ln_recov_tot_t
	ln_recov_tot_c
	ln_recov_tot_a
	
	ln_gross_dem_t
	ln_gross_dem_c
	ln_gross_dem_a
	
	ln_recoveryrate_t
	ln_recoveryrate_c
	ln_recoveryrate_a
	
	ln_nonexemptrate_t
	ln_nonexemptrate_c
	ln_nonexemptrate_a
;
# delimit cr

use "`analysis_file'", clear
keep if fyear == 2015 & qtr == 4
keep circle_id `vars' partition_id group

* Label variables
forval z =1/3 {
	local x : word `z' of t c a
	local y : word `z' of Total Current Arrears
		
	label var ln_recov_tot_`x' "Log Revenue (`y')"
	label var ln_gross_dem_`x' "Log Tax Base (`y')"
	label var ln_recoveryrate_`x' "Log Recovery Rate (`y')"
	label var ln_nonexemptrate_`x' "Log Non-Exemption Rate (`y')"
	

}

* Order variables
order circle_id ln_recov_tot_t ln_recov_tot_c ln_recov_tot_a ///
				ln_gross_dem_t ln_gross_dem_c ln_gross_dem_a ///
				ln_nonexemptrate_t ln_nonexemptrate_c ln_nonexemptrate_a ///
				ln_recoveryrate_t ln_recoveryrate_c ln_recoveryrate_a


* Save the mean of the variables of interest
eststo means: estpost tabstat `vars', statistics(mean) columns(statistics)

* Calculate the overall standard deviation
foreach var in `vars' {
	egen sd_`var' = sd(`var')
}

* Save standard deviation
ren ln* temp_ln*
ren sd_ln* ln*
eststo sds: estpost tabstat `vars', statistics(mean) columns(statistics)
ren ln* sd_ln*
ren temp_ln* ln*

* Calcualte the within group standard deviation for each variable of interest
bys partition_id group : gen first_in_group = _n == 1
foreach var in `vars' {
	bys partition_id group : egen group_sd_`var' = sd(`var')
	egen mean_group_sd_`var' = mean(group_sd_`var') if first_in_group == 1
	drop group_sd_`var'
}
drop first_in_group

* Save mean of within-group standard deviation
ren ln* temp_ln*
ren mean_group_sd_ln* ln*
eststo group_sds: estpost tabstat `vars', statistics(mean) columns(statistics)
ren ln* mean_group_sd_ln*
ren temp_ln* ln*

* Calculate the number of non-missing values for each variable of interest
foreach var in `vars' {
	egen n_`var' = count(`var')
}

* Save number of observations, N
ren ln* temp_ln*
ren n_ln* ln*
eststo obs: estpost tabstat `vars', statistics(mean) columns(statistics)
ren ln* n_ln*
ren temp_ln* ln*

* Draw table
esttab means sds group_sds obs using "${TP_PAPER_OUTPUT}/tex/input/summary_stats_input.tex", ///
	cells("mean(label(Mean) fmt(%12.2fc))") ///
	mtitles("Mean" "SD" "\specialcell{Mean of \\ within-group SD}" "N") ///
	nostar noobs nonumbers nonote label booktabs fragment collabels(none) ///
	replace

local file summary_stats

** WRITE TABLE NOTE
file open tablenote using "${TP_PAPER_OUTPUT}/tex/notes/`file'_notes.txt", write replace

file write tablenote "Statistics from administrative data are shown at the end of Year 2 of the study (FY 2015). Each observation is one of the 525 circles as defined at the time of randomization."
	
file close tablenote


texout2 "${TP_PAPER_OUTPUT}/tex/`file'", ///
  input("input/`file'_input") notes("notes/`file'_notes")

* Cleans the .tex file by removing extra decimals in the N column
shell python "`python_file'"

compiletex "${TP_PAPER_OUTPUT}/tex/`file'.tex", ///
  out("..") aux("auxdir/") 
  
